@@ -13,7 +13,7 @@ import struct
 import binascii
 from collections import namedtuple
 
-__version__ = '1.0.4'
+__version__ = '1.0.5'
 
 WORD = 2   # bytes
 DWORD = 4  # bytes, double word
@@ -2281,6 +2281,10 @@ class File(object):
     def closed(self):
         return self.f.closed
 
+    @property
+    def mapname(self):
+        return self.map_name
+
     def _read_header(self):
         f = self.f
         self.loc = 28
@@ -2448,6 +2452,8 @@ class File(object):
         # compute inc
         if self._lastleft is None:
             inc = False
+        elif self._lastleft is not None and (len(self.players) <=2):
+            inc = True
         else:
             inc = (unknownflag == (self._lastleft.unknownflag + 1))
         # compute closedby and reult
@@ -2571,6 +2577,15 @@ class File(object):
                     return ITEMS_TO_RACE[e.ability]
         return p.race
 
+    @lru_cache(13)
+    def player_race_random(self, pid):
+        p = self.player(pid)
+        if p.race == 'none' and isinstance(p, Player):
+            p = self.slot_record(pid)
+        if p.race == 'random':
+            return True
+        return False
+
     def print_apm(self):
         acts = {p.id: 0 for p in self.players}
         for e in self.events:
@@ -2657,6 +2672,15 @@ class File(object):
                 return e.player_id
         raise RuntimeError("Winner could not be found")
 
+    @lru_cache(13)
+    def map(self):
+
+        if self.map:
+            return self.map
+        else:
+            return "No map found"
+
+
 def main():
     f = File(sys.argv[1])
     for event in f.events:
